user

package
v0.0.0-...-0bafe12 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 11, 2024 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the user type in the database.
	Label = "user"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldT holds the string denoting the t field in the database.
	FieldT = "t"
	// FieldURL holds the string denoting the url field in the database.
	FieldURL = "url"
	// FieldURLs holds the string denoting the urls field in the database.
	FieldURLs = "urls"
	// FieldRaw holds the string denoting the raw field in the database.
	FieldRaw = "raw"
	// FieldDirs holds the string denoting the dirs field in the database.
	FieldDirs = "dirs"
	// FieldInts holds the string denoting the ints field in the database.
	FieldInts = "ints"
	// FieldFloats holds the string denoting the floats field in the database.
	FieldFloats = "floats"
	// FieldStrings holds the string denoting the strings field in the database.
	FieldStrings = "strings"
	// FieldIntsValidate holds the string denoting the ints_validate field in the database.
	FieldIntsValidate = "ints_validate"
	// FieldFloatsValidate holds the string denoting the floats_validate field in the database.
	FieldFloatsValidate = "floats_validate"
	// FieldStringsValidate holds the string denoting the strings_validate field in the database.
	FieldStringsValidate = "strings_validate"
	// FieldAddr holds the string denoting the addr field in the database.
	FieldAddr = "addr"
	// FieldUnknown holds the string denoting the unknown field in the database.
	FieldUnknown = "unknown"
	// Table holds the table name of the user in the database.
	Table = "users"
)

Variables

var (
	// DefaultDirs holds the default value on creation for the "dirs" field.
	DefaultDirs func() []http.Dir
	// DefaultInts holds the default value on creation for the "ints" field.
	DefaultInts []int
	// IntsValidateValidator is a validator for the "ints_validate" field. It is called by the builders before save.
	IntsValidateValidator func([]int) error
	// FloatsValidateValidator is a validator for the "floats_validate" field. It is called by the builders before save.
	FloatsValidateValidator func([]float64) error
	// StringsValidateValidator is a validator for the "strings_validate" field. It is called by the builders before save.
	StringsValidateValidator func([]string) error
)

Columns holds all SQL columns for user fields.

Functions

func AddrIsNil

func AddrIsNil() predicate.User

AddrIsNil applies the IsNil predicate on the "addr" field.

func AddrNotNil

func AddrNotNil() predicate.User

AddrNotNil applies the NotNil predicate on the "addr" field.

func And

func And(predicates ...predicate.User) predicate.User

And groups predicates with the AND operator between them.

func FloatsIsNil

func FloatsIsNil() predicate.User

FloatsIsNil applies the IsNil predicate on the "floats" field.

func FloatsNotNil

func FloatsNotNil() predicate.User

FloatsNotNil applies the NotNil predicate on the "floats" field.

func FloatsValidateIsNil

func FloatsValidateIsNil() predicate.User

FloatsValidateIsNil applies the IsNil predicate on the "floats_validate" field.

func FloatsValidateNotNil

func FloatsValidateNotNil() predicate.User

FloatsValidateNotNil applies the NotNil predicate on the "floats_validate" field.

func ID

func ID(id int) predicate.User

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.User

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.User

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.User

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.User

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.User

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.User

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.User

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.User

IDNotIn applies the NotIn predicate on the ID field.

func IntsIsNil

func IntsIsNil() predicate.User

IntsIsNil applies the IsNil predicate on the "ints" field.

func IntsNotNil

func IntsNotNil() predicate.User

IntsNotNil applies the NotNil predicate on the "ints" field.

func IntsValidateIsNil

func IntsValidateIsNil() predicate.User

IntsValidateIsNil applies the IsNil predicate on the "ints_validate" field.

func IntsValidateNotNil

func IntsValidateNotNil() predicate.User

IntsValidateNotNil applies the NotNil predicate on the "ints_validate" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.User) predicate.User

Or groups predicates with the OR operator between them.

func RawIsNil

func RawIsNil() predicate.User

RawIsNil applies the IsNil predicate on the "raw" field.

func RawNotNil

func RawNotNil() predicate.User

RawNotNil applies the NotNil predicate on the "raw" field.

func StringsIsNil

func StringsIsNil() predicate.User

StringsIsNil applies the IsNil predicate on the "strings" field.

func StringsNotNil

func StringsNotNil() predicate.User

StringsNotNil applies the NotNil predicate on the "strings" field.

func StringsValidateIsNil

func StringsValidateIsNil() predicate.User

StringsValidateIsNil applies the IsNil predicate on the "strings_validate" field.

func StringsValidateNotNil

func StringsValidateNotNil() predicate.User

StringsValidateNotNil applies the NotNil predicate on the "strings_validate" field.

func TIsNil

func TIsNil() predicate.User

TIsNil applies the IsNil predicate on the "t" field.

func TNotNil

func TNotNil() predicate.User

TNotNil applies the NotNil predicate on the "t" field.

func URLIsNil

func URLIsNil() predicate.User

URLIsNil applies the IsNil predicate on the "url" field.

func URLNotNil

func URLNotNil() predicate.User

URLNotNil applies the NotNil predicate on the "url" field.

func URLsIsNil

func URLsIsNil() predicate.User

URLsIsNil applies the IsNil predicate on the "URLs" field.

func URLsNotNil

func URLsNotNil() predicate.User

URLsNotNil applies the NotNil predicate on the "URLs" field.

func UnknownIsNil

func UnknownIsNil() predicate.User

UnknownIsNil applies the IsNil predicate on the "unknown" field.

func UnknownNotNil

func UnknownNotNil() predicate.User

UnknownNotNil applies the NotNil predicate on the "unknown" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the User queries.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

Jump to