Documentation
¶
Index ¶
- Constants
- Variables
- func AddrIsNil() predicate.User
- func AddrNotNil() predicate.User
- func And(predicates ...predicate.User) predicate.User
- func FloatsIsNil() predicate.User
- func FloatsNotNil() predicate.User
- func FloatsValidateIsNil() predicate.User
- func FloatsValidateNotNil() predicate.User
- func ID(id int) predicate.User
- func IDEQ(id int) predicate.User
- func IDGT(id int) predicate.User
- func IDGTE(id int) predicate.User
- func IDIn(ids ...int) predicate.User
- func IDLT(id int) predicate.User
- func IDLTE(id int) predicate.User
- func IDNEQ(id int) predicate.User
- func IDNotIn(ids ...int) predicate.User
- func IntsIsNil() predicate.User
- func IntsNotNil() predicate.User
- func IntsValidateIsNil() predicate.User
- func IntsValidateNotNil() predicate.User
- func Not(p predicate.User) predicate.User
- func Or(predicates ...predicate.User) predicate.User
- func RawIsNil() predicate.User
- func RawNotNil() predicate.User
- func StringsIsNil() predicate.User
- func StringsNotNil() predicate.User
- func StringsValidateIsNil() predicate.User
- func StringsValidateNotNil() predicate.User
- func TIsNil() predicate.User
- func TNotNil() predicate.User
- func URLIsNil() predicate.User
- func URLNotNil() predicate.User
- func URLsIsNil() predicate.User
- func URLsNotNil() predicate.User
- func UnknownIsNil() predicate.User
- func UnknownNotNil() predicate.User
- func ValidColumn(column string) bool
- type OrderOption
Constants ¶
const ( // Label holds the string label denoting the user type in the database. Label = "user" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldT holds the string denoting the t field in the database. FieldT = "t" // FieldURL holds the string denoting the url field in the database. FieldURL = "url" // FieldURLs holds the string denoting the urls field in the database. FieldURLs = "urls" // FieldRaw holds the string denoting the raw field in the database. FieldRaw = "raw" // FieldDirs holds the string denoting the dirs field in the database. FieldDirs = "dirs" // FieldInts holds the string denoting the ints field in the database. FieldInts = "ints" // FieldFloats holds the string denoting the floats field in the database. FieldFloats = "floats" // FieldStrings holds the string denoting the strings field in the database. FieldStrings = "strings" // FieldIntsValidate holds the string denoting the ints_validate field in the database. FieldIntsValidate = "ints_validate" // FieldFloatsValidate holds the string denoting the floats_validate field in the database. FieldFloatsValidate = "floats_validate" // FieldStringsValidate holds the string denoting the strings_validate field in the database. FieldStringsValidate = "strings_validate" // FieldAddr holds the string denoting the addr field in the database. FieldAddr = "addr" // FieldUnknown holds the string denoting the unknown field in the database. FieldUnknown = "unknown" // Table holds the table name of the user in the database. Table = "users" )
Variables ¶
var ( // DefaultDirs holds the default value on creation for the "dirs" field. DefaultDirs func() []http.Dir // DefaultInts holds the default value on creation for the "ints" field. DefaultInts []int // IntsValidateValidator is a validator for the "ints_validate" field. It is called by the builders before save. IntsValidateValidator func([]int) error // FloatsValidateValidator is a validator for the "floats_validate" field. It is called by the builders before save. FloatsValidateValidator func([]float64) error // StringsValidateValidator is a validator for the "strings_validate" field. It is called by the builders before save. StringsValidateValidator func([]string) error )
var Columns = []string{ FieldID, FieldT, FieldURL, FieldURLs, FieldRaw, FieldDirs, FieldInts, FieldFloats, FieldStrings, FieldIntsValidate, FieldFloatsValidate, FieldStringsValidate, FieldAddr, FieldUnknown, }
Columns holds all SQL columns for user fields.
Functions ¶
func AddrNotNil ¶
AddrNotNil applies the NotNil predicate on the "addr" field.
func FloatsIsNil ¶
FloatsIsNil applies the IsNil predicate on the "floats" field.
func FloatsNotNil ¶
FloatsNotNil applies the NotNil predicate on the "floats" field.
func FloatsValidateIsNil ¶
FloatsValidateIsNil applies the IsNil predicate on the "floats_validate" field.
func FloatsValidateNotNil ¶
FloatsValidateNotNil applies the NotNil predicate on the "floats_validate" field.
func IntsNotNil ¶
IntsNotNil applies the NotNil predicate on the "ints" field.
func IntsValidateIsNil ¶
IntsValidateIsNil applies the IsNil predicate on the "ints_validate" field.
func IntsValidateNotNil ¶
IntsValidateNotNil applies the NotNil predicate on the "ints_validate" field.
func StringsIsNil ¶
StringsIsNil applies the IsNil predicate on the "strings" field.
func StringsNotNil ¶
StringsNotNil applies the NotNil predicate on the "strings" field.
func StringsValidateIsNil ¶
StringsValidateIsNil applies the IsNil predicate on the "strings_validate" field.
func StringsValidateNotNil ¶
StringsValidateNotNil applies the NotNil predicate on the "strings_validate" field.
func URLsNotNil ¶
URLsNotNil applies the NotNil predicate on the "URLs" field.
func UnknownIsNil ¶
UnknownIsNil applies the IsNil predicate on the "unknown" field.
func UnknownNotNil ¶
UnknownNotNil applies the NotNil predicate on the "unknown" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the User queries.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.